==> qtstalker-0.28.tar.gz: qtstalker/plugins/indicator/MACD/MACD.h <==
/*
 *  Qtstalker stock charter
 *
 *  Copyright (C) 2001-2004 Stefan S. Stratigakos
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 */

#include "IndicatorPlugin.h"

class MACD : public IndicatorPlugin
{
  public:
    MACD ();
    virtual ~MACD ();
    void calculate ();
    void loadIndicatorSettings (QString);
    void saveIndicatorSettings (QString);
    int indicatorPrefDialog (QWidget *);
    void setDefaults();
    PlotLine * calculateCustom (QDict<PlotLine> *);
    Setting getIndicatorSettings ();
    void setIndicatorSettings (Setting);

  private:
    QColor macdColor;
    QColor trigColor;
    QColor oscColor;
    PlotLine::LineType macdLineType;
    PlotLine::LineType trigLineType;
    PlotLine::LineType oscLineType;
    QString macdLabel;
    QString trigLabel;
    QString oscLabel;
    int fastPeriod;
    int slowPeriod;
    int trigPeriod;
    IndicatorPlugin::MAType macdMAType;
    BarData::InputType macdInput;
    bool oscScaleFlag;
    QString customInput;
    QString label;
};

extern "C"
{
  IndicatorPlugin * createIndicatorPlugin ();
}

==> qtstalker_0.32.orig.tar.gz: qtstalker/plugins/indicator/MACD/MACD.h <==
/*
 *  Qtstalker stock charter
 *
 *  Copyright (C) 2001-2005 Stefan S. Stratigakos
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 */

#include "IndicatorPlugin.h"

class MACD : public IndicatorPlugin
{
  public:
    MACD ();
    virtual ~MACD ();
    void calculate ();
    int indicatorPrefDialog (QWidget *);
    void setDefaults();
    PlotLine * calculateCustom (QDict<PlotLine> *);
    void getIndicatorSettings (Setting &);
    void setIndicatorSettings (Setting &);
    int getMinBars ();

  private:
    QColor macdColor;
    QColor trigColor;
    QColor oscColor;
    PlotLine::LineType macdLineType;
    PlotLine::LineType trigLineType;
    PlotLine::LineType oscLineType;
    QString macdLabel;
    QString trigLabel;
    QString oscLabel;
    int fastPeriod;
    int slowPeriod;
    int trigPeriod;
    int macdMAType;
    BarData::InputType macdInput;
    bool oscScaleFlag;
    QString customInput;
    QString label;
};

extern "C"
{
  IndicatorPlugin * createIndicatorPlugin ();
}
